@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-# Copyright (C) 1999, 2000 Milan Zamazal
+# Copyright (C) 1999, 2000, 2001 Milan Zamazal
 #
 # COPYRIGHT NOTICE
 #
@@ -25,8 +25,8 @@
 This module is very ugly and is intended to be rewritten sometimes.
 """
 
-__author__  = "Milan Zamazal <pdm@freesoft.cz>"
-__version__ = "$Id: cgiscript.py,v 1.28 2000/09/08 20:04:56 pdm Exp $"
+__author__  = "Milan Zamazal <pdm@zamazal.org>"
+__version__ = "$Id: cgiscript.py,v 1.30 2001/04/15 07:26:01 pdm Exp $"
 __copyright__ = "GNU General Public License, version 2"
 
 
@@ -48,7 +48,7 @@ from gnats2w.i18n import L
 # Constants
 
 
-VERSION = '0.14'
+VERSION = '0.15'
 
 
 # Reporting errors
@@ -459,6 +459,10 @@ def submit (form):
     for k in ('description', 'how-to-repeat', 'fix', 'environment'):
         if form.has_key (k):
             form[k] = remove_crs (form[k])
+    if not form.has_key ('submitter-id'):
+        form['submitter-id'] = 'unknown'
+    if not form.has_key ('state'):
+        form['state'] = 'open'
     p = problem.Problem (G, form)
     if p.ok () and G.submit (p):
         output_document ('submit-ok', {'problem': p, 'dump': html_dump (p)})
@@ -521,6 +525,7 @@ def edit (form):
             v = string.strip (v)
             new_items[k] = v
             if k == 'category' and \
+               v != items['category'] and \
                (not form.has_key ('responsible')
                 or form['responsible'] == items['responsible']):
                 cats = categories_full ()
@@ -973,7 +978,7 @@ def go (form=None):
         global BASIC_PARAMS
         BASIC_PARAMS = {'adminmail': config.ADMIN_MAIL}
         global G
-        G = gnats.Gnats ()
+        G = config.GNATS
         global BASIC_PARAMS
         BASIC_PARAMS.update ({'gen_submit_url': gen_submit_url})
         versions = '%s, gnats2w %s' % (G.version (), VERSION)
