@@ -26,8 +26,8 @@ provided through the class 'Gnats'.
 GNATS databases are accessed only by GNATS commands (both public and internal).
 """
 
-__author__  = "Milan Zamazal <pdm@freesoft.cz>"
-__version__ = "$Id: gnats.py,v 1.20 2000/07/24 19:08:44 pdm Exp $"
+__author__  = "Milan Zamazal <pdm@zamazal.org>"
+__version__ = "$Id: gnats.py,v 1.23 2001/04/15 17:41:16 pdm Exp $"
 __copyright__ = "GNU General Public License, version 2"
 
 
@@ -46,7 +46,7 @@ from gnats2w.i18n import L
 # Classes
 
 
-class Gnats:
+class Gnats3:
     """Gnats database accessor.
 
     It provides the following groups of methods:
@@ -389,7 +389,7 @@ class Gnats:
 
 
     def classes_full (self):
-        """Return a list of all information about responsible persons.
+        """Return a list of all information about problem classes.
 
         The list contains lists of the form [CLASS, TYPE, DESCRIPTION].
         CLASS is the class name.
@@ -767,6 +767,8 @@ Content-Type: text/plain; charset=%s
                 value = items[string.lower (f)]
             except KeyError:
                 value = ''
+            if value == None:
+                value = ''
             if f in self._GTAGS_MULTILINE:
                 linesplit = string.split (value, '\n')
                 for i in range (len (linesplit)):
@@ -826,3 +828,71 @@ Content-Type: text/plain; charset=%s
             return update + '\n' + old
         else:
             return old
+
+
+class Gnats4 (Gnats3):
+    """Customization of the GNATS accessor for GNATS 4.
+    """
+
+    __SPECIAL_TAGS = ('Responsible-Changed-Why',
+                      'State-Changed-Why',
+                      'Unformatted')
+    
+    _GTAGS = Gnats3._GTAGS[:-1] + __SPECIAL_TAGS
+    
+    _GTAGS_MULTILINE = Gnats3._GTAGS_MULTILINE[:-1] + __SPECIAL_TAGS
+    
+    
+    def _directory_command (self, command):
+        """Add appropriate '--database' to 'command' if needed.
+
+        Return the resulting string.
+        """
+        if self._directory:
+            command = command + (" --database='%s' " % \
+                                 self._protect (self._directory))
+        return command
+        
+        
+    def categories (self):
+        return self._extract_first (self.categories_full ())
+
+
+    def classes_full (self):
+        command = self._directory_command ('query-pr --valid-values=class')
+        try:
+            items = []
+            f = os.popen (command)
+            while 1:
+                line = f.readline ()
+                if not line:
+                    break
+                items.append ([line, 'class', ''])
+            f.close ()
+            return items
+        except:
+            return None        
+
+    def update_trail (self, items, changes, changer,
+                      reason_responsible, reason_state):
+        """Return new audit trail as a string.
+
+        Arguments:
+
+          items -- problem dictionary of original values
+          changes -- problem dictionary of udpated values
+          changer -- identification of the person, who performed the changes
+          reason_responsible -- reason for changing responsible
+          reason_state -- reason for changing state
+        """
+        if reason_responsible:
+            changes['responsible-changed-why'] = reason_responsible
+        if reason_state:
+            changes['state-changed-why'] = reason_state
+        try:
+            return items['audit-trail']
+        except KeyError:
+            return ''
+
+
+Gnats = Gnats4
