@@ -26,8 +26,8 @@ is independent on both GNATS backend (format of storage) and WWW frontend
 its methods.
 """
 
-__author__  = "Milan Zamazal <pdm@freesoft.cz>"
-__version__ = "$Id: problem.py,v 1.12 2000/06/13 19:18:23 pdm Exp $"
+__author__  = "Milan Zamazal <pdm@zamazal.org>"
+__version__ = "$Id: problem.py,v 1.14 2001/04/15 07:26:22 pdm Exp $"
 __copyright__ = "GNU General Public License, version 2"
 
 
@@ -101,6 +101,7 @@ class Problem:
                 result = result + L("Required item `%s' empty.\n" % k)
         # Test the latest changes
         if self._changes.has_key ('responsible') and \
+           self._changes['responsible'] != items['responsible'] and \
            not self._reason_responsible and \
            not self._changes.has_key ('category'):
             result = result + \
